@@ -3,15 +3,13 @@
 # no sane linter can figure out the hackiness in this compatability layer...
 
 try:
-    from astroid.nodes import ClassDef, FunctionDef, ImportFrom, AssignName, Attribute
+    from astroid.nodes import AssignName, Attribute, ClassDef, FunctionDef, ImportFrom
 except ImportError:
-    from astroid.nodes import (
-        Class as ClassDef,
-        Function as FunctionDef,
-        From as ImportFrom,
-        AssName as AssignName,
-        Getattr as Attribute,
-    )
+    from astroid.nodes import AssName as AssignName
+    from astroid.nodes import Class as ClassDef
+    from astroid.nodes import From as ImportFrom
+    from astroid.nodes import Function as FunctionDef
+    from astroid.nodes import Getattr as Attribute
 
 # pylint 2.04->2.2 : YES was renamed to Uninferable, then YES became deprecated, then was removed
 try:
@@ -27,6 +25,6 @@ import pylint
 # pylint before version 2.3 does not support load_configuration() hook.
 LOAD_CONFIGURATION_SUPPORTED = False
 try:
-    LOAD_CONFIGURATION_SUPPORTED = tuple(pylint.__version__.split('.')) >= ('2', '3')
+    LOAD_CONFIGURATION_SUPPORTED = tuple(pylint.__version__.split(".")) >= ("2", "3")
 except AttributeError:
     LOAD_CONFIGURATION_SUPPORTED = pylint.__pkginfo__.numversion >= (2, 3)
