@@ -2,15 +2,18 @@ import csv
 import os
 import pickle
 import sys
+from pathlib import Path
 
 import pylint
 import pytest
 
 os.environ.setdefault("DJANGO_SETTINGS_MODULE", "pylint_django.tests.settings")
 
+HERE = Path(__file__).parent
+
 try:
     # pylint 2.5: test_functional has been moved to pylint.testutils
-    from pylint.testutils import FunctionalTestFile, LintModuleTest
+    from pylint.testutils import FunctionalTestFile, LintModuleTest, lint_module_test
 
     if "test" not in csv.list_dialects():
 
@@ -19,6 +22,8 @@ try:
             lineterminator = "\n"
 
         csv.register_dialect("test", test_dialect)
+
+    lint_module_test.PYLINTRC = HERE / "testing_pylint.rc"
 except (ImportError, AttributeError):
     # specify directly the directory containing test_functional.py
     test_functional_dir = os.getenv("PYLINT_TEST_FUNCTIONAL_DIR", "")
@@ -37,11 +42,7 @@ except (ImportError, AttributeError):
     from test_functional import FunctionalTestFile, LintModuleTest
 
 
-# alter sys.path again because the tests now live as a subdirectory
-# of pylint_django
-sys.path.append(os.path.join(os.path.dirname(__file__), "..", ".."))
-# so we can find migrations
-sys.path.append(os.path.join(os.path.dirname(__file__), "input"))
+sys.path += [str(p.absolute()) for p in (HERE, HERE / "../../", HERE / "input")]
 
 
 class PylintDjangoLintModuleTest(LintModuleTest):
@@ -50,6 +51,7 @@ class PylintDjangoLintModuleTest(LintModuleTest):
     """
 
     def __init__(self, test_file):
+        # if hasattr(test_file, 'option_file') and test_file.option_file is None:
         super(PylintDjangoLintModuleTest, self).__init__(test_file)
         self._linter.load_plugin_modules(["pylint_django"])
         self._linter.load_plugin_configuration()
@@ -71,13 +73,12 @@ def get_tests(input_dir="input", sort=False):
     def _file_name(test):
         return test.base
 
-    HERE = os.path.dirname(os.path.abspath(__file__))
-    input_dir = os.path.join(HERE, input_dir)
+    input_dir = HERE / input_dir
 
     suite = []
-    for fname in os.listdir(input_dir):
-        if fname != "__init__.py" and fname.endswith(".py"):
-            suite.append(FunctionalTestFile(input_dir, fname))
+    for fname in input_dir.iterdir():
+        if fname.name != "__init__.py" and fname.name.endswith(".py"):
+            suite.append(FunctionalTestFile(str(input_dir.absolute()), str(fname.absolute())))
 
     # when testing the migrations plugin we need to sort by input file name
     # because the plugin reports the errors in close() which appends them to the
@@ -114,7 +115,7 @@ def test_migrations_plugin(test_file):
 
 
 @pytest.mark.parametrize("test_file", MIGRATIONS_TESTS[:1], ids=MIGRATIONS_TESTS_NAMES[:1])
-def test_linter_should_be_pickleable_with_pylint_djang_plugin_installed(test_file):
+def test_linter_should_be_pickleable_with_pylint_django_plugin_installed(test_file):
     LintTest = PylintDjangoMigrationsTest(test_file)
     LintTest.setUp()
 
